/**
	ADF4351-628v1.h

	Firmware pour piloter un circuit DDS : AD9951.
	par Silicium628.

	Ce fichier source "AD9951.h" est libre, vous pouvez le redistribuer et/ou le modifier selon
	les termes de la Licence Publique Générale GNU.
**/


#ifndef ADF4351_628v1_h
#define ADF4351_628v1_h

#pragma once

#define port_ADF4351 PORTF  // sur portF

#define	pin_CLK			0b10000000		// (sortie) sur portF
#define	pin_DATA		0b01000000		// (sortie) sur portF
#define	pin_LE			0b00100000		// (sortie) sur portF
#define	pin_MUXOUT	0b00010000		// (*ENTREE*) sur portF

class ADF4351
{

public:

	ADF4351(byte);
	void initialize(int, int); // Initialize with initial frequency, refClk (defaults to 10Mhz);

	// powers down the PLL/VCO
	void powerDown(bool);
	void setRfPower(int);
	void setAuxPower(int);
	void auxEnable(bool);
	void rfEnable(bool);

	// Gets current frequency
	int getFreq();

	// Sets frequency
	void setFreq(int);

	void setInt(int);

	void setFeedbackType(bool);

	void update();

	unsigned long _phase;
	unsigned long _freq, _int, _divider, _refClk, _auxPower, _rfPower;
	
private:
	// Instance variables that hold pinout mapping
	byte _ssPin;

	// Instance variables for ...
	bool _powerdown, _auxEnabled, _rfEnabled, _feedbackType;

	// register values
	byte _r0[4], _r1[4], _r2[4], _r3[4], _r4[4], _r5[4];

	// function to write data to register.
	void setR0();
	void setR1();
	void setR2();
	void setR3();
	void setR4();
	void setR5();
	void writeRegister(byte[4]);	


};

#endif
