/**
	ADF4351-628v2.h

	Firmware pour piloter un circuit DDS : ADF4351
	avec un AVR atmega2560

**/


#ifndef	ADF4351_628V2_H
#define	ADF4351_628V2_H

#pragma	once

#define	port_ADF4351 PORTF  // sur portF
#define	port_PIN_ADF4351 PINF

#define	pin_CLK			0b10000000		// (sortie) sur portF
#define	pin_DATA		0b01000000		// (sortie) sur portF
#define	pin_LE			0b00100000		// (sortie) sur portF
#define	pin_MUXOUT	0b00010000		// (*ENTREE*) sur PINF
#define	pin_CE			0b00001000		// (sortie) sur portF

class ADF4351
{

public:

	uint32_t registers[6] = {0x4580A8, 0x80080C9, 0x4E42, 0x4B3, 0xBC803C, 0x580005};
	uint32_t memo_registers[6] = {0, 0, 0, 0, 0, 0};

	uint32_t RFint, RFintold, INTA, RFcalc, PDRFout, MOD, FRAC;

	double RFout, REFin, PFDRFout, OutputChannelSpacing, FRACF;
	
	double RFoutMin = 35; // 35 MHz
	double RFoutMax = 4400; // 4400MHz = 4.4 GHz
	double REFinMax = 250;
	double PDFMax = 32;
			
	uint8_t DIV;
	uint8_t lock=2;
	
	ADF4351();
	
	void init();
	
	void reset_LE();
	void set_LE();
	void reset_DATA();
	void set_DATA();
	void mute(uint8_t valeur);
	void impulse_clk();
	void impulse_LE();
	void out1octet(uint8_t octet_i);
	void Write_Register32(const uint32_t data);   //Programme un registre 32bits
	void Write_All_Register(); // Programme tous les registres de l'ADF4351
	void setFreq(double frequence);  // en MHz (avec decimales)
	
private:

	bool _powerdown, _auxEnabled, _rfEnabled, _feedbackType;

};

#endif
